NAME
Time::DaysInMonth -- simply report the number of days in a month
SYNOPSIS
use Time::DaysInMonth;
$days = days_in($year, $month_1_to_12);
$leapyear = is_leap($year);
DESCRIPTION
DaysInMonth is simply a package to report the number of days in a month. That's all it does. Really!
AUTHOR
Best Practical Solutions, LLC <modules@bestpractical.com>
ORIGINAL AUTHOR
David Muir Sharnoff
BUGS
This only deals with the "modern" calendar. Look elsewhere for historical time and date support.
LICENSE AND COPYRIGHT
Copyright (C) 1996-1999 David Muir Sharnoff. Copyright (C) 2026 Best Practical Solutions, LLC.
This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.